UpdateUsingInstant

Struct UpdateUsingInstant 

pub struct UpdateUsingInstant { /* private fields */ }
Implementation of update aspect using Instant.

Implementations

Source

impl UpdateUsingInstant

pub fn should_update(&mut self, update_rate: f32) -> bool

Check if an update should happen. If an update should happen, then the time of calling this function is recorded to compare against the next call time.