pub struct UpdateUsingInstant { /* private fields */ }Expand description
Implementation of update aspect using Instant.
Implementations
Sourceimpl UpdateUsingInstant
impl UpdateUsingInstant
Sourcepub fn should_update(&mut self, update_rate: f32) -> bool
pub fn should_update(&mut self, update_rate: f32) -> bool
Check if an update should happen. If an update should happen, then the time of calling this function is recorded to compare against the next call time.